"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mistralai.types import BaseModel
from typing_extensions import TypedDict


class ProcessingStatusOutTypedDict(TypedDict):
    document_id: str
    processing_status: str


class ProcessingStatusOut(BaseModel):
    document_id: str

    processing_status: str
