"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mistralai_azure.types import BaseModel
import pydantic
from typing import Literal
from typing_extensions import Annotated, TypedDict


Format = Literal[
    "markdown",
    "html",
]
r"""Format of the table"""


class OCRTableObjectTypedDict(TypedDict):
    id: str
    r"""Table ID for extracted table in a page"""
    content: str
    r"""Content of the table in the given format"""
    format_: Format
    r"""Format of the table"""


class OCRTableObject(BaseModel):
    id: str
    r"""Table ID for extracted table in a page"""

    content: str
    r"""Content of the table in the given format"""

    format_: Annotated[Format, pydantic.Field(alias="format")]
    r"""Format of the table"""
