"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .contentchunk import ContentChunk, ContentChunkTypedDict
from mistralai.types import BaseModel, Nullable, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Literal, Optional, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


UserMessageContentTypedDict = TypeAliasType(
    "UserMessageContentTypedDict", Union[str, List[ContentChunkTypedDict]]
)


UserMessageContent = TypeAliasType("UserMessageContent", Union[str, List[ContentChunk]])


UserMessageRole = Literal["user",]


class UserMessageTypedDict(TypedDict):
    content: Nullable[UserMessageContentTypedDict]
    role: NotRequired[UserMessageRole]


class UserMessage(BaseModel):
    content: Nullable[UserMessageContent]

    role: Optional[UserMessageRole] = "user"

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["role"]
        nullable_fields = ["content"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
