"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .systemmessagecontentchunks import (
    SystemMessageContentChunks,
    SystemMessageContentChunksTypedDict,
)
from mistralai.types import BaseModel
from typing import List, Literal, Optional, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


SystemMessageContentTypedDict = TypeAliasType(
    "SystemMessageContentTypedDict",
    Union[str, List[SystemMessageContentChunksTypedDict]],
)


SystemMessageContent = TypeAliasType(
    "SystemMessageContent", Union[str, List[SystemMessageContentChunks]]
)


Role = Literal["system",]


class SystemMessageTypedDict(TypedDict):
    content: SystemMessageContentTypedDict
    role: NotRequired[Role]


class SystemMessage(BaseModel):
    content: SystemMessageContent

    role: Optional[Role] = "system"
