"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mistralai.types import BaseModel
from typing_extensions import TypedDict


class FileSignedURLTypedDict(TypedDict):
    url: str


class FileSignedURL(BaseModel):
    url: str
