"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .functioncall import FunctionCall, FunctionCallTypedDict
from .tooltypes import ToolTypes
from mistralai.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ToolCallTypedDict(TypedDict):
    function: FunctionCallTypedDict
    id: NotRequired[str]
    type: NotRequired[ToolTypes]
    index: NotRequired[int]


class ToolCall(BaseModel):
    function: FunctionCall

    id: Optional[str] = "null"

    type: Optional[ToolTypes] = None

    index: Optional[int] = 0
