"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mistralai_azure.types import BaseModel
from mistralai_azure.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PredictionTypedDict(TypedDict):
    r"""Enable users to specify an expected completion, optimizing response times by leveraging known or predictable content."""

    type: Literal["content"]
    content: NotRequired[str]


class Prediction(BaseModel):
    r"""Enable users to specify an expected completion, optimizing response times by leveraging known or predictable content."""

    TYPE: Annotated[
        Annotated[
            Optional[Literal["content"]], AfterValidator(validate_const("content"))
        ],
        pydantic.Field(alias="type"),
    ] = "content"

    content: Optional[str] = ""
