"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing import Literal


TranscriptionStreamEventTypes = Literal[
    "transcription.language",
    "transcription.segment",
    "transcription.text.delta",
    "transcription.done",
]
