"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mistralai_azure.types import UnrecognizedStr
from typing import Literal, Union


MistralPromptMode = Union[Literal["reasoning",], UnrecognizedStr]
